@@ -59,12 +59,10 @@ use base qw( Exporter DynaLoader );
 sub dl_load_flags { 0x01 } # global option
 
 BEGIN {
-  $VERSION = '1.04';
+  $VERSION = '1.05';
   bootstrap Net::Silk $VERSION;
 }
 
-use Scalar::Util qw( looks_like_number );
-
 use constant DEBUG => 0;
 
 module_init($FindBin::Script);
@@ -182,15 +180,15 @@ END { module_destroy() }
 
 ###
 
-use Net::Silk::IPWildcard;
-use Net::Silk::Site;
-use Net::Silk::IPAddr;
-use Net::Silk::IPSet;
-use Net::Silk::ProtoPort;
-use Net::Silk::Pmap;
-use Net::Silk::File;
-use Net::Silk::Bag;
-use Net::Silk::TCPFlags;
+require Net::Silk::IPWildcard;
+require Net::Silk::Site;
+require Net::Silk::IPAddr;
+require Net::Silk::IPSet;
+require Net::Silk::ProtoPort;
+require Net::Silk::Pmap;
+require Net::Silk::File;
+require Net::Silk::Bag;
+require Net::Silk::TCPFlags;
 
 ###
 
